﻿using System;
using System.Diagnostics;
using System.IO;
using System.Windows.Forms;

namespace WatchForChange
{
    public partial class MainForm : Form
    {
        FileSystemWatcher Watcher;

        public MainForm()
        {
            InitializeComponent();
        }

        private void MainForm_Resize(object sender, EventArgs e)
        {
            if (this.WindowState == FormWindowState.Minimized) this.Hide();
        }

        private void niTrayIcon_MouseClick(object sender, MouseEventArgs e)
        {
            this.Show();
        }

        private void StartWatch(string WatchDir)
        {
            Watcher = new FileSystemWatcher(WatchDir);
            Watcher.IncludeSubdirectories = cbIncludeSubdirs.Checked;
            
            Watcher.Created += new FileSystemEventHandler(Watcher_Event);
            if (!cbNewFiles.Checked)
            {
                Watcher.Changed += new FileSystemEventHandler(Watcher_Event);
                Watcher.Deleted += new FileSystemEventHandler(Watcher_Event);
            }
            Watcher.EnableRaisingEvents = true;
        }

        void Watcher_Event(object sender, FileSystemEventArgs e)
        {
            this.BeginInvoke((MethodInvoker)delegate
            {
                Process.Start(tbAppPath.Text, tbArgs.Text.Replace("%f", "\"" + e.FullPath + "\""));
            });
        }

        private void tbWatchDir_TextChanged(object sender, EventArgs e)
        {
            if (!string.IsNullOrEmpty(tbWatchDir.Text) && !string.IsNullOrEmpty(tbAppPath.Text)) btToggleWatch.Enabled = true;
        }

        private void tbAppPath_TextChanged(object sender, EventArgs e)
        {
            if (!string.IsNullOrEmpty(tbWatchDir.Text) && !string.IsNullOrEmpty(tbAppPath.Text)) btToggleWatch.Enabled = true;
        }

        private void cbIncludeSubdirs_CheckedChanged(object sender, EventArgs e)
        {
            if(Watcher!= null) Watcher.IncludeSubdirectories = cbIncludeSubdirs.Checked;
        }

        private void cbNewFiles_CheckedChanged(object sender, EventArgs e)
        {
            if (!string.IsNullOrEmpty(tbWatchDir.Text) && !string.IsNullOrEmpty(tbAppPath.Text)) btToggleWatch.Enabled = true;
        }

        private void btBrowseDir_Click(object sender, EventArgs e)
        {
            FolderBrowserDialog FolderBrowser = new FolderBrowserDialog();
            if (FolderBrowser.ShowDialog(this) == DialogResult.OK)
            {
                tbWatchDir.Text = FolderBrowser.SelectedPath;
            }
        }

        private void btAppBrowse_Click(object sender, EventArgs e)
        {
            OpenFileDialog FileBrowser = new OpenFileDialog();
            if (FileBrowser.ShowDialog(this) == DialogResult.OK)
            {
                tbAppPath.Text = FileBrowser.FileName;
            }
        }

        private void btToggleWatch_Click(object sender, EventArgs e)
        {
            if (Watcher == null)
            {
                if (!string.IsNullOrEmpty(tbWatchDir.Text) && !string.IsNullOrEmpty(tbAppPath.Text))
                {
                    StartWatch(tbWatchDir.Text);
                    btToggleWatch.Text = "Pause Watching";
                }
            }
            else
            {
                Watcher.Dispose();
                Watcher = null;
                btToggleWatch.Text = "Start Watching";
            }
        }
    }
}
